@@ -15,8 +15,6 @@ QString ArticleParser::parseArticleContent(QString article)
     //remove tables
     while (article.contains(QRegExp("\\<table[^\\>]+\\>")))
     {
-        qDebug()<< "start "<< article.indexOf(QRegExp("\\<table[^\\>]+\\>"));
-        qDebug()<< "end " << article.indexOf(QRegExp("\\</table\\>"));
         int start = article.indexOf(QRegExp("\\<table[^\\>]+\\>"));
         int end = article.indexOf(QRegExp("\\</table\\>"));
         if (article.indexOf(QRegExp("\\</table\\>")) <=  article.indexOf(QRegExp("\\<table[^\\>]+\\>")))
@@ -40,6 +38,5 @@ QString ArticleParser::parseArticleContent(QString article)
     {
         article.remove(article.lastIndexOf("References"), article.count());
     }
-    qDebug()<<article;
     return article;
 }
