@@ -391,7 +391,8 @@ void MainWindow::addToPlaylist(QString playlistname, QString item)
 {
     qDebug()<<playlistname<<item;
     message->setLabelText("Saving");
-    message->setParent(articleList);
+    articleList->hide();
+   // message->setParent(articleList);
     message->show();
     network->retrieveArticle(item, false, this->toPlaylist);
     playlist->addToPlaylist(playlistname, item);
@@ -445,6 +446,7 @@ void MainWindow::audioCreated()
         this->toPlaylist = false;
       //  qDebug()<<"c"<<item;
         message->hide();
+        this->articleList->show();
     }
 }
 
